controllers

package
v0.0.0-...-ea634ce Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2018 License: MIT Imports: 5 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type StatusController

type StatusController struct{}

StatusController describes a status controller.

func (StatusController) Get

func (s StatusController) Get(c *gin.Context)

Get a user public data.

type UserController

type UserController struct{}

UserController describes a user controller.

func (UserController) Get

func (u UserController) Get(c *gin.Context)

Get retrieves the authenticated user data.

func (UserController) Post

func (u UserController) Post(c *gin.Context)

Post creates a new database entry for the authenticated user.

func (UserController) Put

func (u UserController) Put(c *gin.Context)

Put update the authenticated user data.

type UserTokenController

type UserTokenController struct{}

UserTokenController class.

func (UserTokenController) Get

func (u UserTokenController) Get(c *gin.Context)

Get a user token challenge from a Purse Account address hash.

func (UserTokenController) Post

func (u UserTokenController) Post(c *gin.Context)

Post a user token challenge from a Purse Account address hash.

Jump to